pub enum CReferenceDecodeError {
MisalignedBytes {
len: usize,
},
PartialVastRow {
words: usize,
stride: usize,
},
MismatchedVastRows {
raw_rows: usize,
typed_rows: usize,
},
}Expand description
Malformed byte input for C VAST CPU oracle decoding.
Variants
MisalignedBytes
Input byte length is not a whole number of u32 words.
PartialVastRow
Input word count is not a whole number of VAST rows.
MismatchedVastRows
Two VAST streams that must describe the same node set have different row counts.