pub struct ConditionalEvent {
pub file: PathBuf,
pub kind: ConditionalEventKind,
pub directive_row: u32,
pub directive_byte_offset: u32,
pub depth_before: u32,
pub depth_after: u32,
pub parent_active: bool,
pub truth: Option<bool>,
pub current_active: bool,
pub branch_taken: bool,
pub directive_residency: ConditionalEventResidency,
pub state_residency: ConditionalEventResidency,
}Expand description
Conditional-state event emitted by the GPU-resident preprocessor driver.
Fields
file: PathBufFile that contained the conditional directive.
kind: ConditionalEventKindConditional directive kind.
directive_row: u32Directive row in the classified token stream.
directive_byte_offset: u32Byte offset of the directive token in the filtered source.
depth_before: u32Stack depth before applying this directive.
depth_after: u32Stack depth after applying this directive.
parent_active: boolParent active state before applying this directive.
truth: Option<bool>Truth value for #if, #elif, #ifdef, and #ifndef when evaluated.
current_active: boolCurrent active state after applying this directive.
branch_taken: boolWhether any branch in this conditional group has been taken after applying this directive.
directive_residency: ConditionalEventResidencyResidency of directive row/payload extraction.
state_residency: ConditionalEventResidencyResidency of truth evaluation or stack transition.