pub struct CLineSplicedSource {
pub bytes: Vec<u8>,
pub original_offsets: Vec<usize>,
}Expand description
Source bytes after C translation phase 2 line splicing.
bytes contains the source with every backslash-newline pair deleted.
original_offsets maps each output byte boundary back to the input byte
boundary at the same logical position. Its length is always
bytes.len() + 1, with the final entry pointing at source.len().
Fields
bytes: Vec<u8>Phase-2 source bytes with line-splice pairs removed.
original_offsets: Vec<usize>Output byte-boundary to original byte-boundary map.
Implementations
Sourceimpl CLineSplicedSource
impl CLineSplicedSource
Sourcepub fn original_offset(&self, logical_offset: usize) -> usize
pub fn original_offset(&self, logical_offset: usize) -> usize
Map a logical byte boundary in bytes back to an original source offset.