pub enum RustLowerError {
NoEntryFunction,
Unsupported(String),
}Expand description
Errors from Rust to Vyre IR lowering.
Variants
NoEntryFunction
The module declares no function to use as the entry kernel.
Unsupported(String)
A construct outside the wired lowering subset was encountered.