Module scan_program

Module scan_program 

Neutral NFA scan composition artifact.

This module owns program and immutable table construction only. Dispatch, resident allocation, readback, and timing adapters live above vyre-libs.

Structs

ScanProgram
Typed program plus immutable inputs required by the NFA scan composition.

Functions

build
Build a neutral NFA program artifact and its immutable table inputs.