AnalysisFactError

Enum AnalysisFactError 

pub enum AnalysisFactError {
Show 18 variants InvalidFactId { id: FactId, }, DuplicateFactId { id: FactId, }, InvalidSpan { context: String, start_byte: u32, end_byte: u32, }, InvalidConfidence { id: FactId, confidence_bps: u16, }, MissingInferenceReason { id: FactId, }, SelfProvenance { id: FactId, }, InvalidPayloadKey { id: FactId, }, MissingProvenanceParent { id: FactId, parent: FactId, }, InvalidFindingIdentity { field: &'static str, }, InvalidFindingConfidence { finding_id: String, confidence_bps: u16, }, FindingHasNoFacts { finding_id: String, }, FindingHasNoProofPath { finding_id: String, }, FindingHasNoSoundnessEvidence { finding_id: String, }, FindingSoundnessViolation { finding_id: String, violation: DynamicSoundnessViolation, }, FindingSoundnessMismatch { finding_id: String, declared: Soundness, computed: Soundness, }, FindingReferencesMissingFact { finding_id: String, fact_id: FactId, }, InvalidProofRole { fact_id: FactId, }, UnexpectedFactKind { id: FactId, role: &'static str, expected: String, actual: FactKind, },
}
Analysis fact/finding validation failure.

Variants



InvalidFactId

A fact id was zero.

Fields

id: FactId

Invalid id.



DuplicateFactId

A fact id appeared more than once.

Fields

id: FactId

Duplicate id.



InvalidSpan

A source span had reversed byte order.

Fields

context: String

Span context.

start_byte: u32

Start byte.

end_byte: u32

End byte.



InvalidConfidence

Confidence exceeded 10000 basis points.

Fields

id: FactId

Fact id.

confidence_bps: u16

Invalid confidence.



MissingInferenceReason

Inferred fact had no explanation.

Fields

id: FactId

Fact id.



SelfProvenance

Fact listed itself as provenance.

Fields

id: FactId

Fact id.



InvalidPayloadKey

Payload key was blank.

Fields

id: FactId

Fact id.



MissingProvenanceParent

A provenance parent id was missing.

Fields

id: FactId

Derived fact id.

parent: FactId

Missing parent id.



InvalidFindingIdentity

A finding identity field was blank.

Fields

field: &'static str

Invalid field name.



InvalidFindingConfidence

Finding confidence exceeded 10000 basis points.

Fields

finding_id: String

Finding id.

confidence_bps: u16

Invalid confidence.



FindingHasNoFacts

Finding referenced no facts.

Fields

finding_id: String

Finding id.



FindingHasNoProofPath

Finding had no proof path.

Fields

finding_id: String

Finding id.



FindingHasNoSoundnessEvidence

Finding had no primitive soundness evidence.

Fields

finding_id: String

Finding id.



FindingSoundnessViolation

Finding primitive evidence violated its precision contract.

Fields

finding_id: String

Finding id.

violation: DynamicSoundnessViolation

Canonical dynamic soundness violation.



FindingSoundnessMismatch

Finding declared a composed soundness marker inconsistent with evidence.

Fields

finding_id: String

Finding id.

declared: Soundness

Declared soundness.

computed: Soundness

Computed soundness.



FindingReferencesMissingFact

Finding referenced an absent fact.

Fields

finding_id: String

Finding id.

fact_id: FactId

Missing fact id.



InvalidProofRole

Proof role was blank.

Fields

fact_id: FactId

Fact id.



UnexpectedFactKind

A fact was present but had the wrong kind for its query role.

Fields

id: FactId

Fact id.

role: &'static str

Query role.

expected: String

Expected kind list.

actual: FactKind

Actual fact kind.