pub enum AnalysisFactError {
Show 18 variants
InvalidFactId {
id: FactId,
},
DuplicateFactId {
id: FactId,
},
InvalidSpan {
context: String,
start_byte: u32,
end_byte: u32,
},
InvalidConfidence {
id: FactId,
confidence_bps: u16,
},
MissingInferenceReason {
id: FactId,
},
SelfProvenance {
id: FactId,
},
InvalidPayloadKey {
id: FactId,
},
MissingProvenanceParent {
id: FactId,
parent: FactId,
},
InvalidFindingIdentity {
field: &'static str,
},
InvalidFindingConfidence {
finding_id: String,
confidence_bps: u16,
},
FindingHasNoFacts {
finding_id: String,
},
FindingHasNoProofPath {
finding_id: String,
},
FindingHasNoSoundnessEvidence {
finding_id: String,
},
FindingSoundnessViolation {
finding_id: String,
violation: DynamicSoundnessViolation,
},
FindingSoundnessMismatch {
finding_id: String,
declared: Soundness,
computed: Soundness,
},
FindingReferencesMissingFact {
finding_id: String,
fact_id: FactId,
},
InvalidProofRole {
fact_id: FactId,
},
UnexpectedFactKind {
id: FactId,
role: &'static str,
expected: String,
actual: FactKind,
},
}Expand description
Analysis fact/finding validation failure.
Variants
InvalidFactId
A fact id was zero.
DuplicateFactId
A fact id appeared more than once.
InvalidSpan
A source span had reversed byte order.
InvalidConfidence
Confidence exceeded 10000 basis points.
MissingInferenceReason
Inferred fact had no explanation.
SelfProvenance
Fact listed itself as provenance.
InvalidPayloadKey
Payload key was blank.
MissingProvenanceParent
A provenance parent id was missing.
InvalidFindingIdentity
A finding identity field was blank.
InvalidFindingConfidence
Finding confidence exceeded 10000 basis points.
FindingHasNoFacts
Finding referenced no facts.
FindingHasNoProofPath
Finding had no proof path.
FindingHasNoSoundnessEvidence
Finding had no primitive soundness evidence.
FindingSoundnessViolation
Finding primitive evidence violated its precision contract.
Fields
violation: DynamicSoundnessViolationCanonical dynamic soundness violation.
FindingSoundnessMismatch
Finding declared a composed soundness marker inconsistent with evidence.
Fields
FindingReferencesMissingFact
Finding referenced an absent fact.
InvalidProofRole
Proof role was blank.
UnexpectedFactKind
A fact was present but had the wrong kind for its query role.